/*
	File:		HYPluginProcs.h
	
	Description: iMovie plugin callback procs

	Author:		iMovie Engineering team

	Copyright: 	 Copyright 2003 Apple Computer, Inc. All rights reserved.
	
	Disclaimer:	IMPORTANT:  This Apple software is supplied to you by Apple Computer, Inc.
				("Apple") in consideration of your agreement to the following terms, and your
				use, installation, modification or redistribution of this Apple software
				constitutes acceptance of these terms.  If you do not agree with these terms,
				please do not use, install, modify or redistribute this Apple software.

				In consideration of your agreement to abide by the following terms, and subject
				to these terms, Apple grants you a personal, non-exclusive license, under Apples
				copyrights in this original Apple software (the "Apple Software"), to use,
				reproduce, modify and redistribute the Apple Software, with or without
				modifications, in source and/or binary forms; provided that if you redistribute
				the Apple Software in its entirety and without modifications, you must retain
				this notice and the following text and disclaimers in all such redistributions of
				the Apple Software.  Neither the name, trademarks, service marks or logos of
				Apple Computer, Inc. may be used to endorse or promote products derived from the
				Apple Software without specific prior written permission from Apple.  Except as
				expressly stated in this notice, no other rights or licenses, express or implied,
				are granted by Apple herein, including but not limited to any patent rights that
				may be infringed by your derivative works or by other works in which the Apple
				Software may be incorporated.

				The Apple Software is provided by Apple on an "AS IS" basis.  APPLE MAKES NO
				WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED
				WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
				PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS USE AND OPERATION ALONE OR IN
				COMBINATION WITH YOUR PRODUCTS.

				IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR
				CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
				GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
				ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION
				OF THE APPLE SOFTWARE, HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT
				(INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
				ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
				
	Change History (most recent first):

*/

#ifndef __HYPluginProcs__
#define __HYPluginProcs__

#ifdef __cplusplus
extern "C" {
#endif

/*
	Note: This file cannot compile stand-alone. 
	It is meant to be included inside HYPluginInterface.h
*/

typedef enum {	// used for whichClip param of GetClipInfo callback:
	kBeforeClip,
	kThisClip,
	kAfterClip,
	// new in version 4:
	kClipContainingFrame		// frame is passed in HYPluginClipInfo.ver4.clipFrame
} WhichClipEnum;

	// memory
	typedef Ptr (*ProxTypeNewPtr) ( Size size );
	typedef Ptr (*ProxTypeNewPtrClear) ( Size size );
	typedef void (*ProxTypeDisposePtr) ( Ptr thePtr );
	
	// string
	typedef void (*ProxTypeptocstr) ( unsigned char *str );
	typedef void (*ProxTypectopstr) ( char *str );
	typedef void (*ProxTypepstrcpy) ( unsigned char *strA, unsigned char *strB );
	typedef char * (*ProxTypestrcpy) ( char *dest, const char *source );
	typedef unsigned long (*ProxTypestrlen) ( const char *str );
	typedef void (*ProxTypeGetLocalizedString) ( unsigned char *string, short rsrcIndex, short strIndex );
	
	// frames
	typedef HYPluginResult (*ProxTypeGetFrame) ( HYPluginInstance instance, long frameNum, GWorldPtr *gWorldPtr,
		short width, short height, HYRefDVQuality quality, short *volume, HYFrameCookie *frameCookie );
	typedef HYPluginResult (*ProxTypeReleaseFrame) ( HYPluginInstance instance, HYFrameCookie frameCookie );
	typedef HYPluginResult (*ProxTypeGetAudioFrame) ( HYPluginInstance plugInstance, long frameNum, short *volume, void **frameCookie );
	typedef HYPluginResult (*ProxTypeReleaseAudioFrame) ( HYPluginInstance instance, void *frameCookie );
	
	// info
	typedef HYPluginResult (*ProxTypeGetMovieInfo) ( HYRefDigitalVideoStandard *standard,
		short *frameWidth, short *frameHeight, long *totalFrames );
	typedef HYPluginResult (*ProxTypeGetClipInfo) ( HYPluginInstance instance, WhichClipEnum whichClip, HYPluginClipInfo *clipInfo );
	typedef HYPluginResult (*ProxTypeSetClipInfo) ( HYPluginInstance instance, HYPluginClipInfo *clipInfo );
		
	// drawing
	typedef HYPluginResult (*ProxTypeBlit) ( PixMap *srcImage, PixMap *dstImage, Rect *srcR, Rect *dstR, short opacity);
	typedef HYPluginResult (*ProxTypeFillRect) ( Rect *fillRect, RGBColor *color, short opacity );
	typedef HYPluginResult (*ProxTypeTextBounds) ( Rect *bounds, Str255 theText, float size, float loxX, float locY, float shadowX, float shadowY );
	typedef HYPluginResult (*ProxTypeDrawText) ( Str255 theText, float size, RGBColor *color,
		short opacity, short antiAlias, float locX, float locY, RGBColor *shadowColor, float shadowX, float shadowY );
	
	// title stuff
	typedef HYPluginResult (*ProxTypeGetTitleInfo) ( HYPluginInstance instance, HYPluginTitleInfo **titleInfo );
	typedef HYPluginResult (*ProxTypeReleaseTitleInfo) ( HYPluginInstance instance, HYPluginTitleInfo *titleInfo );

	// transition stuff
	typedef HYPluginResult (*ProxTypeGetTransitionInfo) ( HYPluginInstance instance, HYPluginTransitionInfo **transitionInfo );
	typedef HYPluginResult (*ProxTypeReleaseTransitionInfo) ( HYPluginInstance instance, HYPluginTransitionInfo *transitionInfo );

	// audio stuff
	typedef HYPluginResult (*ProxTypeMixAudio) ( HYPluginInstance instance, HYFrameCookie sourceFrame, short level );

	/* Beginning of 2.0 API */
	
	// filter stuff
	typedef HYPluginResult (*ProxTypeGetFilterInfo) ( HYPluginInstance instance, HYPluginFilterInfo **filterInfo );
	typedef HYPluginResult (*ProxTypeReleaseFilterInfo) ( HYPluginInstance instance, HYPluginFilterInfo *filterInfo );

	// use this instead of standard StringWidth to handle non-square pixel issues
	typedef float (*ProxTypeStringWidth) ( Str255 theText );

	/* Beginning of 4.0 API */
	typedef HYPluginResult (*ProxTypeCGDrawText) ( Str255 theText, float size, float angle, HYTextAlignment align, RGBColor *color,
		float opacity, float locX, float locY, RGBColor *shadowColor, float shadowX, float shadowY );
	typedef float (*ProxTypeCGStringWidth) ( Str255 theText, float size );


typedef struct _HYProcs {
        ProxTypeNewPtr NewPtr;
		ProxTypeNewPtrClear NewPtrClear;
		ProxTypeDisposePtr DisposePtr;
		
		ProxTypeptocstr ptocstr;
		ProxTypectopstr ctopstr;
		ProxTypepstrcpy pstrcpy;
		ProxTypestrcpy strcpy;
		ProxTypestrlen strlen;
		ProxTypeGetLocalizedString GetLocalizedString;
		
		ProxTypeGetFrame GetFrame;
		ProxTypeReleaseFrame ReleaseFrame;
		ProxTypeGetAudioFrame GetAudioFrame;
		ProxTypeReleaseAudioFrame ReleaseAudioFrame;

		ProxTypeGetMovieInfo GetMovieInfo;
		ProxTypeGetClipInfo GetClipInfo;
		ProxTypeSetClipInfo SetClipInfo;
		
		ProxTypeBlit Blit;
		ProxTypeFillRect FillRect;
		ProxTypeTextBounds TextBounds;
		ProxTypeDrawText DrawText;

		ProxTypeGetTitleInfo GetTitleInfo;
		ProxTypeReleaseTitleInfo ReleaseTitleInfo;
		ProxTypeGetTransitionInfo GetTransitionInfo;
		ProxTypeReleaseTransitionInfo ReleaseTransitionInfo;
		
		ProxTypeMixAudio MixAudio;
		
		/* Beginning of 2.0 API */
		ProxTypeGetFilterInfo GetFilterInfo;
		ProxTypeReleaseFilterInfo ReleaseFilterInfo;
		ProxTypeStringWidth StringWidth;
		
		/* Beginning of 4.0 API */
		ProxTypeCGDrawText CGDrawText;
		ProxTypeCGStringWidth CGStringWidth;
		
} HYProcs;

#ifdef __cplusplus
}
#endif

#endif
// __HYPluginProcs__

